{#style_dlg.title}

- {#style_dlg.text_tab}
- {#style_dlg.background_tab}
- {#style_dlg.block_tab}
- {#style_dlg.box_tab}
- {#style_dlg.border_tab}
- {#style_dlg.list_tab}
- {#style_dlg.positioning_tab}

{#style_dlg.text}

{#style_dlg.text_font} |
{#style_dlg.text_size} |
|  | Text Size Measurement Unit
| {#style_dlg.text_weight} |
{#style_dlg.text_style} |  | {#style_dlg.text_variant} |
{#style_dlg.text_lineheight} |
|  | Line Height Measurement Unit
| {#style_dlg.text_case} |
{#style_dlg.text_color} |
{#style_dlg.text_decoration} |
| {#style_dlg.text_underline}
| {#style_dlg.text_overline}
| {#style_dlg.text_striketrough}
| {#style_dlg.text_blink}
| {#style_dlg.text_none}

{#style_dlg.background}

{#style_dlg.background_color} |
{#style_dlg.background_image} |
{#style_dlg.background_repeat} |
{#style_dlg.background_attachment} |
{#style_dlg.background_hpos} |
|  | Horizontal position measurement unit
{#style_dlg.background_vpos} |
|  | Vertical position measurement unit

{#style_dlg.block}

{#style_dlg.block_wordspacing} |
|  | Word spacing measurement unit
{#style_dlg.block_letterspacing} |
|  | Letter spacing measurement unit
{#style_dlg.block_vertical_alignment} |
{#style_dlg.block_text_align} |
{#style_dlg.block_text_indent} |
|  | Text Indent Measurement Unit
{#style_dlg.block_whitespace} |
{#style_dlg.block_display} |

{#style_dlg.box}

{#style_dlg.box_width} |
|  | Box Width Measurement Unit
| {#style_dlg.box_float} |
{#style_dlg.box_height} |
|  | Box Height Measurement Unit
| {#style_dlg.box_clear} |

{#style_dlg.padding}

| {#style_dlg.same}
{#style_dlg.top} |
|  | Padding Top Measurement Unit
{#style_dlg.right} |
|  | Padding Right Measurement Unit
{#style_dlg.bottom} |
|  | Padding Bottom Measurement Unit
{#style_dlg.left} |
|  | Padding Left Measurement Unit

{#style_dlg.margin}

| {#style_dlg.same}
{#style_dlg.top} |
|  | Margin Top Measurement Unit
{#style_dlg.right} |
|  | Margin Right Measurement Unit
{#style_dlg.bottom} |
|  | Margin Bottom Measurement Unit
{#style_dlg.left} |
|  | Margin Left Measurement Unit

{#style_dlg.border}

|  | {#style_dlg.style} |  | {#style_dlg.width} |  | {#style_dlg.color}
|  | {#style_dlg.same} |  | {#style_dlg.same} |  | {#style_dlg.same}
{#style_dlg.top} |  |  |  |
|  | Width top Measurement Unit
{#style_dlg.right} |  |  |  |
|  | Width Right Measurement Unit
{#style_dlg.bottom} |  |  |  |
|  | Width Bottom Measurement Unit
{#style_dlg.left} |  |  |  |
|  | Width Left Measurement Unit

{#style_dlg.list}

{#style_dlg.list_type} |
{#style_dlg.bullet_image} |
{#style_dlg.position} |

{#style_dlg.position}

{#style_dlg.positioning_type} |  | {#style_dlg.visibility} |
{#style_dlg.width} |
|  | Positioning width Measurement Unit
| {#style_dlg.zindex} |
{#style_dlg.height} |
|  | Positioning Height Measurement Unit
| {#style_dlg.overflow} |

{#style_dlg.placement}

| {#style_dlg.same}
{#style_dlg.top} |
|  | Placement Top Measurement Unit
{#style_dlg.right} |
|  | Placement Right Measurement Unit
{#style_dlg.bottom} |
|  | Placement Bottom Measurement Unit
{#style_dlg.left} |
|  | Placement Left Measurement Unit

{#style_dlg.clip}

| {#style_dlg.same}
{#style_dlg.top} |
|  | Clip Top Measurement Unit
{#style_dlg.right} |
|  | Clip Right Measurement Unit
{#style_dlg.bottom} |
|  | Clip Bottom Measurement Unit
{#style_dlg.left} |
|  | Clip Left Measurement Unit

{#style_dlg.toggle_insert_span}